@@ -3,20 +3,18 @@ var namespaceSteinberg =
     [ "FUnknownImpl", "namespaceSteinberg_1_1FUnknownImpl.html", "namespaceSteinberg_1_1FUnknownImpl" ],
     [ "FUnknownPrivate", "namespaceSteinberg_1_1FUnknownPrivate.html", [
       [ "atomicAdd", "namespaceSteinberg_1_1FUnknownPrivate.html#aeab173beb18bb16a5737f9fbe0a45289", null ],
-      [ "iidEqual", "namespaceSteinberg_1_1FUnknownPrivate.html#aa492cc7f50f5f6bfb7bd727a115e211e", null ]
+      [ "iidEqual", "namespaceSteinberg_1_1FUnknownPrivate.html#afbf1ba7f286964b19e55474c2905eae4", null ]
     ] ],
     [ "GeoConstants", "namespaceSteinberg_1_1GeoConstants.html", [
-      [ "toOpposite", "namespaceSteinberg_1_1GeoConstants.html#aff2eb279b5ae69049a3283a004a0fce2", null ],
-      [ "toOrientation", "namespaceSteinberg_1_1GeoConstants.html#a94f8ae4df9a9950ee4332d29456d12e9", null ],
-      [ "toOrthogonalOrientation", "namespaceSteinberg_1_1GeoConstants.html#a1f7b523a922afe5e4fc87ecc6dfd2a7d", null ]
+      [ "toOpposite", "namespaceSteinberg_1_1GeoConstants.html#aad3372dfdeb4f43befc9a773e13a4ab8", null ],
+      [ "toOrientation", "namespaceSteinberg_1_1GeoConstants.html#a708700c46dec5f179f1d6552c7803e84", null ],
+      [ "toOrthogonalOrientation", "namespaceSteinberg_1_1GeoConstants.html#a9d80537f969e17e0c06c973409b52bfd", null ]
     ] ],
     [ "KeyCodes", "namespaceSteinberg_1_1KeyCodes.html", [
-      [ "isModifierOnlyKey", "namespaceSteinberg_1_1KeyCodes.html#ad183c365a06b5560e86a61439e756a19", null ]
+      [ "isModifierOnlyKey", "namespaceSteinberg_1_1KeyCodes.html#a1411be7b25f47e89beedadd3de3ade07", null ]
     ] ],
     [ "Linux", "namespaceSteinberg_1_1Linux.html", "namespaceSteinberg_1_1Linux" ],
-    [ "U", "namespaceSteinberg_1_1U.html", [
-      [ "Unknown", "namespaceSteinberg_1_1U.html#a68f6e121eb237b7f588f0036b056b43b", null ]
-    ] ],
+    [ "U", "namespaceSteinberg_1_1U.html", "namespaceSteinberg_1_1U" ],
     [ "ConstStringTable", "classSteinberg_1_1ConstStringTable.html", "classSteinberg_1_1ConstStringTable" ],
     [ "FReleaser", "structSteinberg_1_1FReleaser.html", "structSteinberg_1_1FReleaser" ],
     [ "FUID", "classSteinberg_1_1FUID.html", "classSteinberg_1_1FUID" ],
@@ -226,77 +224,77 @@ var namespaceSteinberg =
       [ "kGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1ab75347fd43308dc34268db5a181108", null ],
       [ "kDkGray", "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda78c5cc590de98a677b2dc3076c904128", null ]
     ] ],
-    [ "_tstrlen", "namespaceSteinberg.html#aaad70e7610886056aaa8406b5527f6e4", null ],
-    [ "tstrlen", "namespaceSteinberg.html#a51fad7b4c1e3dfa032d4f638ecd68c7a", null ],
-    [ "strlen8", "namespaceSteinberg.html#a350bed0883f4792e7535252b3122dd5b", null ],
-    [ "strlen16", "namespaceSteinberg.html#aae116b01b47bca8e67679337ef48d8d3", null ],
-    [ "_tstrcmp", "namespaceSteinberg.html#a5b890e583940aebf298d42775f74e06c", null ],
-    [ "tstrcmp", "namespaceSteinberg.html#a2f01ef81ad1c686ebb34a97ef4e2d098", null ],
-    [ "strcmp8", "namespaceSteinberg.html#a90dd0a8f52813eb453f60ac1c49559bc", null ],
-    [ "strcmp16", "namespaceSteinberg.html#a9b47c8ef5ed96ca9034e87624f69b890", null ],
-    [ "strcmpT", "namespaceSteinberg.html#a37b00b506c12580a5c0bd542ee101bc6", null ],
-    [ "strcmpT< char8 >", "namespaceSteinberg.html#a3ca0790465e05bbb0ac73faebb2647c3", null ],
-    [ "strcmpT< char16 >", "namespaceSteinberg.html#a52f4986b4a7e22b8242e9dea67d01a37", null ],
-    [ "_tstrncmp", "namespaceSteinberg.html#af344c757ce89bc5ee75715e3e2928936", null ],
-    [ "tstrncmp", "namespaceSteinberg.html#a25694d169804ad218b221f3e101eaee4", null ],
-    [ "strncmp8", "namespaceSteinberg.html#a8f3cca9e30bb739b30be3eca6b891c8f", null ],
-    [ "strncmp16", "namespaceSteinberg.html#a54115da13293d44eaae9ba44a4fa82e2", null ],
-    [ "strncmpT", "namespaceSteinberg.html#ae4561021b57c6b115880606b9af43d49", null ],
-    [ "strncmpT< char8 >", "namespaceSteinberg.html#a886c06efdc697d1140ff0d6390b654b1", null ],
-    [ "strncmpT< char16 >", "namespaceSteinberg.html#ada58d6deb48a2fa3d115398537b0fa93", null ],
-    [ "_tstrcpy", "namespaceSteinberg.html#a669ccacd2f9ec698a6607b93167e9dd1", null ],
-    [ "tstrcpy", "namespaceSteinberg.html#ad34233a9dc3a4291c4f2a06baef6742a", null ],
-    [ "strcpy8", "namespaceSteinberg.html#af71653211e72f068ba65a3b0dc8991cc", null ],
-    [ "strcpy16", "namespaceSteinberg.html#af45ea8dc1206c2ea7f855d90090c09ed", null ],
-    [ "_tstrncpy", "namespaceSteinberg.html#a9b79f8ed3b14204881ab6c511e7d3dd6", null ],
-    [ "tstrncpy", "namespaceSteinberg.html#a768fbbf50f430da794a4c2c616427ab8", null ],
-    [ "strncpy8", "namespaceSteinberg.html#ad155f8a1d6630834342fa04949e55f89", null ],
-    [ "strncpy16", "namespaceSteinberg.html#aa55bb9a8621d4bea7235d7ca7427a77d", null ],
-    [ "_tstrcat", "namespaceSteinberg.html#a197db67eb24f0fd94d53e5d687618c08", null ],
-    [ "tstrcat", "namespaceSteinberg.html#a1c7137093ccb2d47a27e4effc5fcd8c0", null ],
-    [ "strcat8", "namespaceSteinberg.html#aadc5e79534fded2926bde5462fec04ec", null ],
-    [ "strcat16", "namespaceSteinberg.html#ae3f01a7c7eaa82c788b6dffd848d949c", null ],
-    [ "str8ToStr16", "namespaceSteinberg.html#a43172f2a5d34fc811021a16d1a38434d", null ],
-    [ "FIDStringsEqual", "namespaceSteinberg.html#ae609f786a23774a473851d3eddaa22ff", null ],
-    [ "strEmpty", "namespaceSteinberg.html#a6df75d455350d4aaadc70786730f11fa", null ],
-    [ "str8Empty", "namespaceSteinberg.html#a107fdab7d7c86e4f5191a27005a6bbc3", null ],
-    [ "str16Empty", "namespaceSteinberg.html#a51822113d808dc2e0594f7f1c61fa823", null ],
-    [ "getTUID", "namespaceSteinberg.html#afd6bc78c280406220f8af5436c191fff", null ],
-    [ "Min", "namespaceSteinberg.html#adac5f7e0dd537bfda376c3b96dd601f3", null ],
-    [ "Max", "namespaceSteinberg.html#a0c6c7876dc38fc4fedff0501ffd74457", null ],
-    [ "Abs", "namespaceSteinberg.html#aba3ecff4e181af61d1fb90a1ebdddf4b", null ],
-    [ "Sign", "namespaceSteinberg.html#aa79ff23f611f74e51508de6f934d9b74", null ],
-    [ "Bound", "namespaceSteinberg.html#a1d0f063a19e621ae10e8e532e0ce3395", null ],
-    [ "Swap", "namespaceSteinberg.html#afc06120bebe47474d1e6c5bfa4eb66b8", null ],
-    [ "IsApproximateEqual", "namespaceSteinberg.html#af300911d7995de5985af548ee4eadcf4", null ],
-    [ "ToNormalized", "namespaceSteinberg.html#a3b853af91258cfec3aaaf03bff12541b", null ],
-    [ "FromNormalized", "namespaceSteinberg.html#a15c8c1bdcb98836c8074a36c9458c048", null ],
-    [ "operator==", "namespaceSteinberg.html#a2978443758ec8594b15872123119363a", null ],
-    [ "operator!=", "namespaceSteinberg.html#aa3bb730da3e8dd39c4b324d057e430c4", null ],
-    [ "VirtualKeyCodeToChar", "namespaceSteinberg.html#a862d540e903360c185899756ea6f8fa6", null ],
-    [ "CharToVirtualKeyCode", "namespaceSteinberg.html#a826c154067a1494875f963d77bbee8ca", null ],
-    [ "owned", "namespaceSteinberg.html#af4392ab94aba2f5c1df4697aae435f7f", null ],
-    [ "shared", "namespaceSteinberg.html#ad48669ba893591a4e3ed6b131325ecbc", null ],
-    [ "MakeColorSpec", "namespaceSteinberg.html#aa3e0271047ce95a6e8097ece6edd712b", null ],
-    [ "MakeColorSpec", "namespaceSteinberg.html#ae445afc6fd5a0c291ebfa793a174a68f", null ],
-    [ "GetBlue", "namespaceSteinberg.html#a52909a27914fed2be847c64aca5b8a1a", null ],
-    [ "GetGreen", "namespaceSteinberg.html#aefa5c41df3f68bedacc9309e35242615", null ],
-    [ "GetRed", "namespaceSteinberg.html#aa2093d47e98716adb212069f951ff841", null ],
-    [ "GetAlpha", "namespaceSteinberg.html#a51cd02b8f8dac485a264e43521c05477", null ],
-    [ "SetBlue", "namespaceSteinberg.html#a109795f69824760eeffa211649eff625", null ],
-    [ "SetGreen", "namespaceSteinberg.html#a12f3dac75f1b1800ab5aaedba6fcd052", null ],
-    [ "SetRed", "namespaceSteinberg.html#a324ac47a91df3cfbfa8cc3235a6c3e76", null ],
-    [ "SetAlpha", "namespaceSteinberg.html#abcfd5a1efa1ea9f617429acd31a9cc3f", null ],
-    [ "NormalizeColorComponent", "namespaceSteinberg.html#afd838e124bec32788d0ec8efafe64a7e", null ],
-    [ "DenormalizeColorComponent", "namespaceSteinberg.html#a2980404bf67477cd52e41e4c01ac06d0", null ],
-    [ "SetAlphaNorm", "namespaceSteinberg.html#a66d5f0c9546a82c5aa78b665b503d9fd", null ],
-    [ "GetAlphaNorm", "namespaceSteinberg.html#ad78eaefa656353e5d08aeba89ad27279", null ],
-    [ "NormalizeAlpha", "namespaceSteinberg.html#a3e48f70b4cb563c93848c357efc48efd", null ],
-    [ "DenormalizeAlpha", "namespaceSteinberg.html#acca20a890a507ef361864ea1f2914af1", null ],
-    [ "StripAlpha", "namespaceSteinberg.html#a40e3829433bee573a0e88fe838e79d9f", null ],
-    [ "BlendColor", "namespaceSteinberg.html#ad887b85aff864f174833a619cfa5fba9", null ],
-    [ "StringCopy", "namespaceSteinberg.html#a834f3ae48811287ea2a7d456fa51fa47", null ],
-    [ "StringLength", "namespaceSteinberg.html#a4802efd192fbb8c76630410764514377", null ],
+    [ "_tstrlen", "namespaceSteinberg.html#a919216f5d1c976556c67d94c8522db43", null ],
+    [ "tstrlen", "namespaceSteinberg.html#adee0831ed9db758b6d119bf3c3b99e43", null ],
+    [ "strlen8", "namespaceSteinberg.html#a8a76499e90e8d7f44ff14f18f129afcd", null ],
+    [ "strlen16", "namespaceSteinberg.html#af722fba1489836fd17c0f50206e8e262", null ],
+    [ "_tstrcmp", "namespaceSteinberg.html#a290312f8c692123017dfd6ab276f7148", null ],
+    [ "tstrcmp", "namespaceSteinberg.html#a532f4daa08250b5344c193d5ab179454", null ],
+    [ "strcmp8", "namespaceSteinberg.html#a6b08a8f4a4993d488e14cf812807675c", null ],
+    [ "strcmp16", "namespaceSteinberg.html#a9d769cee1cea3e2224b7c2fb9c61e1cb", null ],
+    [ "strcmpT", "namespaceSteinberg.html#a485a5d44628dff8b69863742f214ef8c", null ],
+    [ "strcmpT< char8 >", "namespaceSteinberg.html#a9c04924e4e7bafc6162173aa938ce7ae", null ],
+    [ "strcmpT< char16 >", "namespaceSteinberg.html#ace46dac211111d8384286b1ae2c9689e", null ],
+    [ "_tstrncmp", "namespaceSteinberg.html#a59846763a52e0e182dcf5b1573a7e89e", null ],
+    [ "tstrncmp", "namespaceSteinberg.html#accf894d033204ed519ac2612a46c442d", null ],
+    [ "strncmp8", "namespaceSteinberg.html#a95aadb22dc3e307e7e65db901e771f60", null ],
+    [ "strncmp16", "namespaceSteinberg.html#a91005f5c2c5b338136cf19c7afec6064", null ],
+    [ "strncmpT", "namespaceSteinberg.html#a78350a628df86c106340f08c57f9b8b5", null ],
+    [ "strncmpT< char8 >", "namespaceSteinberg.html#a18016e0ec944a4149fab9503980332e7", null ],
+    [ "strncmpT< char16 >", "namespaceSteinberg.html#a154d134fd010929649c537c38e9937f8", null ],
+    [ "_tstrcpy", "namespaceSteinberg.html#ac6ae1990a6eb57a92f18013ab200fd61", null ],
+    [ "tstrcpy", "namespaceSteinberg.html#a46784fedcaf2cd10c9a0f2614ecdb832", null ],
+    [ "strcpy8", "namespaceSteinberg.html#a79cc5b78e482b56ee792dac1fa4ddc1b", null ],
+    [ "strcpy16", "namespaceSteinberg.html#a1f2971e00b71425e2035c4f946031fd9", null ],
+    [ "_tstrncpy", "namespaceSteinberg.html#a901c5dcbc48f4a6f220bd7d4d5d93c66", null ],
+    [ "tstrncpy", "namespaceSteinberg.html#a663277a04cd2cb23fd812715359350f5", null ],
+    [ "strncpy8", "namespaceSteinberg.html#a125a36f7e942e2b77d76d57d2cc6398d", null ],
+    [ "strncpy16", "namespaceSteinberg.html#ad1477e38cb33dbf399ba506dd9fa1ab2", null ],
+    [ "_tstrcat", "namespaceSteinberg.html#a84be4b87ef6295be6b4ea97052b94999", null ],
+    [ "tstrcat", "namespaceSteinberg.html#ad878d42e7b5a81c513f613c52a5f9f0a", null ],
+    [ "strcat8", "namespaceSteinberg.html#a37115f1ed1a36ba151d84ff370aaf05f", null ],
+    [ "strcat16", "namespaceSteinberg.html#a05fbb76593f6044ac8375e1becf16d4d", null ],
+    [ "str8ToStr16", "namespaceSteinberg.html#a65d41e28de7b3ce39de0f9e2e6d99926", null ],
+    [ "FIDStringsEqual", "namespaceSteinberg.html#afcb1a763178c9806cc827360a02741e2", null ],
+    [ "strEmpty", "namespaceSteinberg.html#a6a838f230987e1a095b0cb75c28d4a65", null ],
+    [ "str8Empty", "namespaceSteinberg.html#a728f0ddc16a12be5fa0f950f4c8a0a8e", null ],
+    [ "str16Empty", "namespaceSteinberg.html#a81eef9745d0b6653c6a1c78bb89533d8", null ],
+    [ "getTUID", "namespaceSteinberg.html#ab5c714b140d499f304e042e746ca9b1b", null ],
+    [ "Min", "namespaceSteinberg.html#a29948ccdc9190054dba415d7ac893768", null ],
+    [ "Max", "namespaceSteinberg.html#ae861849d924547696801cead672d8b16", null ],
+    [ "Abs", "namespaceSteinberg.html#a6618cd408bb7e6ca706d2ede559b7883", null ],
+    [ "Sign", "namespaceSteinberg.html#a89abcadbf71668d5248488e4b94eacc6", null ],
+    [ "Bound", "namespaceSteinberg.html#ac5974f8c0577e9e37f9ea9d9d5a70a75", null ],
+    [ "Swap", "namespaceSteinberg.html#a1bab287b1f45fc8d99493a1d142b7deb", null ],
+    [ "IsApproximateEqual", "namespaceSteinberg.html#a004e46ded0d442c0c031094559ad23b6", null ],
+    [ "ToNormalized", "namespaceSteinberg.html#a31a33bd1d2143601be9244b5eb666167", null ],
+    [ "FromNormalized", "namespaceSteinberg.html#a53b9fdb1691391567d0bd6697ddc503c", null ],
+    [ "operator==", "namespaceSteinberg.html#a8a42998c5c8a3a844cdf3b21d1b9be70", null ],
+    [ "operator!=", "namespaceSteinberg.html#a443dbd34922bff48d94a4060764ae9e9", null ],
+    [ "VirtualKeyCodeToChar", "namespaceSteinberg.html#abb64176847a23e106203af14083e1827", null ],
+    [ "CharToVirtualKeyCode", "namespaceSteinberg.html#a9a49a1a97b367d7069b1f6515261fe3e", null ],
+    [ "owned", "namespaceSteinberg.html#a603b2ada00778d1a71caef40362ae6d8", null ],
+    [ "shared", "namespaceSteinberg.html#aecbafba4ac9e0f4734fdc1d0aecc5f70", null ],
+    [ "MakeColorSpec", "namespaceSteinberg.html#a58b97116e0faaf335c798a65b687e9f2", null ],
+    [ "MakeColorSpec", "namespaceSteinberg.html#aa7cb190cb494b7f61aaacf170d322d30", null ],
+    [ "GetBlue", "namespaceSteinberg.html#a25a9f00585fee6f2dda46514bb29b933", null ],
+    [ "GetGreen", "namespaceSteinberg.html#a7daea0aeaaf968f0cbc3473815ef4c4c", null ],
+    [ "GetRed", "namespaceSteinberg.html#a7deed6801721823ffd280717b6675c48", null ],
+    [ "GetAlpha", "namespaceSteinberg.html#a7ef9ebfedc0532d783ae68dbbe8f08c7", null ],
+    [ "SetBlue", "namespaceSteinberg.html#a145379c6e26917acaa0bac72b8c0bc05", null ],
+    [ "SetGreen", "namespaceSteinberg.html#ae8f11c779bd10486d527d1a7142d8e6b", null ],
+    [ "SetRed", "namespaceSteinberg.html#a69a06ce98bc91e355a0b3f558344b0f2", null ],
+    [ "SetAlpha", "namespaceSteinberg.html#aabd2ebacd043630aac6ea6383bace10b", null ],
+    [ "NormalizeColorComponent", "namespaceSteinberg.html#aa50131d71c879a95dfa3efac24b815c6", null ],
+    [ "DenormalizeColorComponent", "namespaceSteinberg.html#abad8045987a3d33b9421e724c06a9d6f", null ],
+    [ "SetAlphaNorm", "namespaceSteinberg.html#a272ecb0af547f0b5e960144874fc8027", null ],
+    [ "GetAlphaNorm", "namespaceSteinberg.html#a572daddd6ee8f61011dcd066eef99b0c", null ],
+    [ "NormalizeAlpha", "namespaceSteinberg.html#a170abdd6288ad80f6ddca3d7e9c3fb59", null ],
+    [ "DenormalizeAlpha", "namespaceSteinberg.html#abfe74133ed684fa31c7227a9d1a4b3ce", null ],
+    [ "StripAlpha", "namespaceSteinberg.html#a27f6f9da6429b67343a7e36078494bd9", null ],
+    [ "BlendColor", "namespaceSteinberg.html#a82f9ae0460c5ad8b348cdfa75fec5c68", null ],
+    [ "StringCopy", "namespaceSteinberg.html#a51c63740ab18a5e8a1394fb10e743917", null ],
+    [ "StringLength", "namespaceSteinberg.html#ae6cdc2936b352ab9cd2fb6aed350bbaa", null ],
     [ "kPlatformStringWin", "namespaceSteinberg.html#a2ae80314db54c6bda33e1cf922effb47", null ],
     [ "kPlatformStringMac", "namespaceSteinberg.html#ad5ffc071fd688ac833b5283777037278", null ],
     [ "kPlatformStringIOS", "namespaceSteinberg.html#a0e747a3b854268949a75a1c8e8fd070c", null ],
