@@ -2,15 +2,15 @@ var NAVTREEINDEX0 =
 {
 "annotated.html":[2,0],
 "classSteinberg_1_1ConstStringTable.html":[1,0,0,6],
-"classSteinberg_1_1ConstStringTable.html":[2,0,0,2],
+"classSteinberg_1_1ConstStringTable.html":[2,0,0,3],
 "classSteinberg_1_1ConstStringTable.html#a99f647d997cd61d511fdf60560c5706b":[1,0,0,6,1],
-"classSteinberg_1_1ConstStringTable.html#a99f647d997cd61d511fdf60560c5706b":[2,0,0,2,1],
-"classSteinberg_1_1ConstStringTable.html#acf88e43da1b31d3d425c80d747bbb1a8":[2,0,0,2,0],
+"classSteinberg_1_1ConstStringTable.html#a99f647d997cd61d511fdf60560c5706b":[2,0,0,3,1],
 "classSteinberg_1_1ConstStringTable.html#acf88e43da1b31d3d425c80d747bbb1a8":[1,0,0,6,0],
+"classSteinberg_1_1ConstStringTable.html#acf88e43da1b31d3d425c80d747bbb1a8":[2,0,0,3,0],
 "classSteinberg_1_1ConstStringTable.html#ad11982e5de305e29fd59bab3e197a4f2":[1,0,0,6,2],
-"classSteinberg_1_1ConstStringTable.html#ad11982e5de305e29fd59bab3e197a4f2":[2,0,0,2,2],
+"classSteinberg_1_1ConstStringTable.html#ad11982e5de305e29fd59bab3e197a4f2":[2,0,0,3,2],
 "classSteinberg_1_1ConstStringTable.html#ae50b58af65ebbc7d1a035d88c520d7dd":[1,0,0,6,3],
-"classSteinberg_1_1ConstStringTable.html#ae50b58af65ebbc7d1a035d88c520d7dd":[2,0,0,2,3],
+"classSteinberg_1_1ConstStringTable.html#ae50b58af65ebbc7d1a035d88c520d7dd":[2,0,0,3,3],
 "classSteinberg_1_1FUID.html":[0,0,0],
 "classSteinberg_1_1FUID.html#a0404d1a9d834c21a3c91a2d9b8c1a361":[0,0,0,4],
 "classSteinberg_1_1FUID.html#a1e809eb52c1b13101a137f4f722d93ab":[0,0,0,20],
@@ -50,36 +50,22 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1FUnknown.html#aaa3c5a2a5410d41153d7f5e3f4e0a635":[0,0,1,1],
 "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl.html":[1,0,0,0,4],
 "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl.html":[2,0,0,0,4],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html":[1,0,0,0,6],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html":[2,0,0,0,6],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a2fcc41284c370068704fcd87160d7099":[1,0,0,0,6,0],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a2fcc41284c370068704fcd87160d7099":[2,0,0,0,6,0],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a5258ca98d4b96ed88ec8368ad216ba85":[1,0,0,0,6,5],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a5258ca98d4b96ed88ec8368ad216ba85":[2,0,0,0,6,5],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a55024c93e14c692864229af868276a77":[2,0,0,0,6,2],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a55024c93e14c692864229af868276a77":[1,0,0,0,6,2],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a664997bd1f020b18ef7dbd1193b5bef5":[2,0,0,0,6,4],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a664997bd1f020b18ef7dbd1193b5bef5":[1,0,0,0,6,4],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#aceeefd83ecd3c2384778ac88c22cf96b":[1,0,0,0,6,3],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#aceeefd83ecd3c2384778ac88c22cf96b":[2,0,0,0,6,3],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#afeeeab8b421d32c39c57ee500cd4f53e":[1,0,0,0,6,1],
-"classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#afeeeab8b421d32c39c57ee500cd4f53e":[2,0,0,0,6,1],
 "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01Base_00_01Indirectly_3_01IndirectInterfaces9a4a5325b3bc049eba78ef3421c75dc0.html":[1,0,0,0,5],
 "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01Base_00_01Indirectly_3_01IndirectInterfaces9a4a5325b3bc049eba78ef3421c75dc0.html":[2,0,0,0,5],
 "classSteinberg_1_1FUnknownPtr.html":[1,0,0,10],
-"classSteinberg_1_1FUnknownPtr.html":[2,0,0,6],
-"classSteinberg_1_1FUnknownPtr.html#a24254b5cf187cab371540748f64d190d":[2,0,0,6,2],
+"classSteinberg_1_1FUnknownPtr.html":[2,0,0,7],
 "classSteinberg_1_1FUnknownPtr.html#a24254b5cf187cab371540748f64d190d":[1,0,0,10,2],
-"classSteinberg_1_1FUnknownPtr.html#a2e3f1f023934674b6f10da8d9451bee0":[2,0,0,6,1],
+"classSteinberg_1_1FUnknownPtr.html#a24254b5cf187cab371540748f64d190d":[2,0,0,7,2],
 "classSteinberg_1_1FUnknownPtr.html#a2e3f1f023934674b6f10da8d9451bee0":[1,0,0,10,1],
-"classSteinberg_1_1FUnknownPtr.html#a3b69dbe73ca0aad8d01137af7a140c27":[2,0,0,6,3],
+"classSteinberg_1_1FUnknownPtr.html#a2e3f1f023934674b6f10da8d9451bee0":[2,0,0,7,1],
 "classSteinberg_1_1FUnknownPtr.html#a3b69dbe73ca0aad8d01137af7a140c27":[1,0,0,10,3],
+"classSteinberg_1_1FUnknownPtr.html#a3b69dbe73ca0aad8d01137af7a140c27":[2,0,0,7,3],
 "classSteinberg_1_1FUnknownPtr.html#a64e510576b14830e0b7dc30ec863cadb":[1,0,0,10,5],
-"classSteinberg_1_1FUnknownPtr.html#a64e510576b14830e0b7dc30ec863cadb":[2,0,0,6,5],
-"classSteinberg_1_1FUnknownPtr.html#ab0a0024a95295f9771675b21f78dc97f":[2,0,0,6,0],
+"classSteinberg_1_1FUnknownPtr.html#a64e510576b14830e0b7dc30ec863cadb":[2,0,0,7,5],
 "classSteinberg_1_1FUnknownPtr.html#ab0a0024a95295f9771675b21f78dc97f":[1,0,0,10,0],
+"classSteinberg_1_1FUnknownPtr.html#ab0a0024a95295f9771675b21f78dc97f":[2,0,0,7,0],
 "classSteinberg_1_1FUnknownPtr.html#ac580abcf2012c88ed8c1023ce525610e":[1,0,0,10,4],
-"classSteinberg_1_1FUnknownPtr.html#ac580abcf2012c88ed8c1023ce525610e":[2,0,0,6,4],
+"classSteinberg_1_1FUnknownPtr.html#ac580abcf2012c88ed8c1023ce525610e":[2,0,0,7,4],
 "classSteinberg_1_1FVariant.html":[0,0,2],
 "classSteinberg_1_1FVariant.html#a02221250eb24a108ec57297d5df2d9de":[0,0,2,6],
 "classSteinberg_1_1FVariant.html#a06497d24a7be077e2c9f261f09a1eb3a":[0,0,2,31],
@@ -131,34 +117,34 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1FVariant.html#af4c9462d5f17112ed3538017f60a623e":[0,0,2,24],
 "classSteinberg_1_1FVariant.html#af9b2e23a8f32ca09cfeb7d828436fb01":[0,0,2,44],
 "classSteinberg_1_1FVariant.html#afe5b3274209fa0f482c22a244de2773d":[0,0,2,22],
-"classSteinberg_1_1IAttributes.html":[2,0,0,8],
 "classSteinberg_1_1IAttributes.html":[1,0,0,12],
+"classSteinberg_1_1IAttributes.html":[2,0,0,9],
 "classSteinberg_1_1IAttributes.html#a0acec6253406938017badc88407f7286":[1,0,0,12,3],
-"classSteinberg_1_1IAttributes.html#a0acec6253406938017badc88407f7286":[2,0,0,8,3],
-"classSteinberg_1_1IAttributes.html#a1c72961487139a9f07d9f78f694ad406":[2,0,0,8,1],
+"classSteinberg_1_1IAttributes.html#a0acec6253406938017badc88407f7286":[2,0,0,9,3],
+"classSteinberg_1_1IAttributes.html#a0ba9fecabcbf74309a19ea33bb11dec8":[1,0,0,12,5],
+"classSteinberg_1_1IAttributes.html#a0ba9fecabcbf74309a19ea33bb11dec8":[2,0,0,9,5],
 "classSteinberg_1_1IAttributes.html#a1c72961487139a9f07d9f78f694ad406":[1,0,0,12,1],
+"classSteinberg_1_1IAttributes.html#a1c72961487139a9f07d9f78f694ad406":[2,0,0,9,1],
 "classSteinberg_1_1IAttributes.html#a1ed9fd6a18bc87466a1b51476c7408e8":[1,0,0,12,0],
-"classSteinberg_1_1IAttributes.html#a1ed9fd6a18bc87466a1b51476c7408e8":[2,0,0,8,0],
+"classSteinberg_1_1IAttributes.html#a1ed9fd6a18bc87466a1b51476c7408e8":[2,0,0,9,0],
 "classSteinberg_1_1IAttributes.html#a2eb44c7c95112fe29e5ce46f097fd22b":[1,0,0,12,7],
-"classSteinberg_1_1IAttributes.html#a2eb44c7c95112fe29e5ce46f097fd22b":[2,0,0,8,7],
-"classSteinberg_1_1IAttributes.html#a67a60bd7651f28dd4de2adf8c8d29d7a":[2,0,0,8,6],
+"classSteinberg_1_1IAttributes.html#a2eb44c7c95112fe29e5ce46f097fd22b":[2,0,0,9,7],
 "classSteinberg_1_1IAttributes.html#a67a60bd7651f28dd4de2adf8c8d29d7a":[1,0,0,12,6],
-"classSteinberg_1_1IAttributes.html#a840cf9568441164595e1468258f4fa3f":[2,0,0,8,2],
+"classSteinberg_1_1IAttributes.html#a67a60bd7651f28dd4de2adf8c8d29d7a":[2,0,0,9,6],
 "classSteinberg_1_1IAttributes.html#a840cf9568441164595e1468258f4fa3f":[1,0,0,12,2],
-"classSteinberg_1_1IAttributes.html#a9078f42ca5569497b403014d65e9d7bd":[2,0,0,8,9],
+"classSteinberg_1_1IAttributes.html#a840cf9568441164595e1468258f4fa3f":[2,0,0,9,2],
 "classSteinberg_1_1IAttributes.html#a9078f42ca5569497b403014d65e9d7bd":[1,0,0,12,9],
-"classSteinberg_1_1IAttributes.html#a9a492c4051f10885bbac87ef1882ea44":[1,0,0,12,5],
-"classSteinberg_1_1IAttributes.html#a9a492c4051f10885bbac87ef1882ea44":[2,0,0,8,5],
+"classSteinberg_1_1IAttributes.html#a9078f42ca5569497b403014d65e9d7bd":[2,0,0,9,9],
 "classSteinberg_1_1IAttributes.html#aa69fa3df16e665aea80acd34d1b9d568":[1,0,0,12,4],
-"classSteinberg_1_1IAttributes.html#aa69fa3df16e665aea80acd34d1b9d568":[2,0,0,8,4],
-"classSteinberg_1_1IAttributes.html#ab7a9881a0b5640523e30e22ddc54fee6":[2,0,0,8,8],
+"classSteinberg_1_1IAttributes.html#aa69fa3df16e665aea80acd34d1b9d568":[2,0,0,9,4],
 "classSteinberg_1_1IAttributes.html#ab7a9881a0b5640523e30e22ddc54fee6":[1,0,0,12,8],
+"classSteinberg_1_1IAttributes.html#ab7a9881a0b5640523e30e22ddc54fee6":[2,0,0,9,8],
 "classSteinberg_1_1IAttributes2.html":[1,0,0,13],
-"classSteinberg_1_1IAttributes2.html":[2,0,0,9],
-"classSteinberg_1_1IAttributes2.html#a564f166842e13ba6a0bf5111d121c36f":[2,0,0,9,1],
+"classSteinberg_1_1IAttributes2.html":[2,0,0,10],
 "classSteinberg_1_1IAttributes2.html#a564f166842e13ba6a0bf5111d121c36f":[1,0,0,13,1],
+"classSteinberg_1_1IAttributes2.html#a564f166842e13ba6a0bf5111d121c36f":[2,0,0,10,1],
 "classSteinberg_1_1IAttributes2.html#afab9fceccb1640882d1a4d112b2c5b96":[1,0,0,13,0],
-"classSteinberg_1_1IAttributes2.html#afab9fceccb1640882d1a4d112b2c5b96":[2,0,0,9,0],
+"classSteinberg_1_1IAttributes2.html#afab9fceccb1640882d1a4d112b2c5b96":[2,0,0,10,0],
 "classSteinberg_1_1IBStream.html":[0,0,3],
 "classSteinberg_1_1IBStream.html#a1449a39ff2d3f964a08753f128626702":[0,0,3,3],
 "classSteinberg_1_1IBStream.html#a25dc574e08d9d76e0c2805bb2f30f7ba":[0,0,3,4],
@@ -169,41 +155,41 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1IBStream.html#aa08e74cc72149c52cd30b35c25efd5b5":[0,0,3,1],
 "classSteinberg_1_1IBStream.html#ae611e1d9d2baf0c9b9490b506ddfcbfd":[0,0,3,2],
 "classSteinberg_1_1ICloneable.html":[1,0,0,15],
-"classSteinberg_1_1ICloneable.html":[2,0,0,11],
-"classSteinberg_1_1ICloneable.html#a12800571f7cffab66e780f66907736d2":[2,0,0,11,0],
+"classSteinberg_1_1ICloneable.html":[2,0,0,12],
 "classSteinberg_1_1ICloneable.html#a12800571f7cffab66e780f66907736d2":[1,0,0,15,0],
+"classSteinberg_1_1ICloneable.html#a12800571f7cffab66e780f66907736d2":[2,0,0,12,0],
 "classSteinberg_1_1IDependent.html":[1,0,0,16],
-"classSteinberg_1_1IDependent.html":[2,0,0,12],
-"classSteinberg_1_1IDependent.html#a3d86c384d513182fbded4f128fc716be":[2,0,0,12,1],
+"classSteinberg_1_1IDependent.html":[2,0,0,13],
 "classSteinberg_1_1IDependent.html#a3d86c384d513182fbded4f128fc716be":[1,0,0,16,1],
+"classSteinberg_1_1IDependent.html#a3d86c384d513182fbded4f128fc716be":[2,0,0,13,1],
 "classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1":[1,0,0,16,0],
-"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1":[2,0,0,12,0],
-"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a12898124f259d06a01da2fbec93b62b7":[2,0,0,12,0,0],
+"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1":[2,0,0,13,0],
 "classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a12898124f259d06a01da2fbec93b62b7":[1,0,0,16,0,0],
+"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a12898124f259d06a01da2fbec93b62b7":[2,0,0,13,0,0],
 "classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a3d6cbd03cda4f9fc9018d975f978a1f1":[1,0,0,16,0,2],
-"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a3d6cbd03cda4f9fc9018d975f978a1f1":[2,0,0,12,0,2],
-"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a59b6e90764ca9aa343f99c0664410110":[2,0,0,12,0,1],
+"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a3d6cbd03cda4f9fc9018d975f978a1f1":[2,0,0,13,0,2],
 "classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a59b6e90764ca9aa343f99c0664410110":[1,0,0,16,0,1],
-"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1ad4ccb3c09b77e5ca9c19831a56d06712":[2,0,0,12,0,4],
+"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a59b6e90764ca9aa343f99c0664410110":[2,0,0,13,0,1],
 "classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1ad4ccb3c09b77e5ca9c19831a56d06712":[1,0,0,16,0,4],
-"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1aefbe6c668f52e8e2dd07b06025691c9e":[2,0,0,12,0,3],
+"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1ad4ccb3c09b77e5ca9c19831a56d06712":[2,0,0,13,0,4],
 "classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1aefbe6c668f52e8e2dd07b06025691c9e":[1,0,0,16,0,3],
-"classSteinberg_1_1IErrorContext.html":[2,0,0,13],
+"classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1aefbe6c668f52e8e2dd07b06025691c9e":[2,0,0,13,0,3],
 "classSteinberg_1_1IErrorContext.html":[1,0,0,17],
+"classSteinberg_1_1IErrorContext.html":[2,0,0,14],
 "classSteinberg_1_1IErrorContext.html#a344d0ab2c2edc4aa4f47af8617375d4f":[1,0,0,17,1],
-"classSteinberg_1_1IErrorContext.html#a344d0ab2c2edc4aa4f47af8617375d4f":[2,0,0,13,1],
+"classSteinberg_1_1IErrorContext.html#a344d0ab2c2edc4aa4f47af8617375d4f":[2,0,0,14,1],
 "classSteinberg_1_1IErrorContext.html#a6984fa8a3247acec65a270803e43bc84":[1,0,0,17,0],
-"classSteinberg_1_1IErrorContext.html#a6984fa8a3247acec65a270803e43bc84":[2,0,0,13,0],
+"classSteinberg_1_1IErrorContext.html#a6984fa8a3247acec65a270803e43bc84":[2,0,0,14,0],
 "classSteinberg_1_1IErrorContext.html#a9d0d7a800ead0504ab9846ee1cbc23e0":[1,0,0,17,2],
-"classSteinberg_1_1IErrorContext.html#a9d0d7a800ead0504ab9846ee1cbc23e0":[2,0,0,13,2],
+"classSteinberg_1_1IErrorContext.html#a9d0d7a800ead0504ab9846ee1cbc23e0":[2,0,0,14,2],
 "classSteinberg_1_1IPersistent.html":[1,0,0,18],
-"classSteinberg_1_1IPersistent.html":[2,0,0,14],
+"classSteinberg_1_1IPersistent.html":[2,0,0,15],
 "classSteinberg_1_1IPersistent.html#a34ba5d29ec54b8d49213549ada3d59fe":[1,0,0,18,2],
-"classSteinberg_1_1IPersistent.html#a34ba5d29ec54b8d49213549ada3d59fe":[2,0,0,14,2],
-"classSteinberg_1_1IPersistent.html#a67e0bc28988160ead2fae757e4f33900":[2,0,0,14,1],
+"classSteinberg_1_1IPersistent.html#a34ba5d29ec54b8d49213549ada3d59fe":[2,0,0,15,2],
 "classSteinberg_1_1IPersistent.html#a67e0bc28988160ead2fae757e4f33900":[1,0,0,18,1],
-"classSteinberg_1_1IPersistent.html#aac250bf48a649ebdab843658f7727039":[2,0,0,14,0],
+"classSteinberg_1_1IPersistent.html#a67e0bc28988160ead2fae757e4f33900":[2,0,0,15,1],
 "classSteinberg_1_1IPersistent.html#aac250bf48a649ebdab843658f7727039":[1,0,0,18,0],
+"classSteinberg_1_1IPersistent.html#aac250bf48a649ebdab843658f7727039":[2,0,0,15,0],
 "classSteinberg_1_1IPlugFrame.html":[0,1,3],
 "classSteinberg_1_1IPlugFrame.html#a94f218315acd695606fff41166294d56":[0,1,3,0],
 "classSteinberg_1_1IPlugView.html":[0,1,2],
@@ -226,9 +212,9 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1IPluginBase.html#a1563a6e0e622483924e5f21242407f16":[0,0,5,1],
 "classSteinberg_1_1IPluginBase.html#a3c81be4ff2e7bbb541d3527264f26eed":[0,0,5,0],
 "classSteinberg_1_1IPluginCompatibility.html":[1,0,0,21],
-"classSteinberg_1_1IPluginCompatibility.html":[2,0,0,17],
-"classSteinberg_1_1IPluginCompatibility.html#a2a70492376238780a9f4adaa333e0b7a":[2,0,0,17,0],
+"classSteinberg_1_1IPluginCompatibility.html":[2,0,0,18],
 "classSteinberg_1_1IPluginCompatibility.html#a2a70492376238780a9f4adaa333e0b7a":[1,0,0,21,0],
+"classSteinberg_1_1IPluginCompatibility.html#a2a70492376238780a9f4adaa333e0b7a":[2,0,0,18,0],
 "classSteinberg_1_1IPluginFactory.html":[0,0,8],
 "classSteinberg_1_1IPluginFactory.html#a22f3efaa3a657a18ff5d2f0f5e916b45":[0,0,8,2],
 "classSteinberg_1_1IPluginFactory.html#a26a0c88f3703edf621060667eab3eb1f":[0,0,8,3],
@@ -249,5 +235,19 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1IPtr.html#a7c145f458643ff993b929f236d4a2ac0":[0,0,12,15],
 "classSteinberg_1_1IPtr.html#a7c7440d29b5a9e86739b1edbe0c09fd3":[0,0,12,10],
 "classSteinberg_1_1IPtr.html#a8146c0b148b276ccca7ce4ac66066fa7":[0,0,12,9],
-"classSteinberg_1_1IPtr.html#a9ef8df82f56d037f33eedf88dc642ac1":[0,0,12,12]
+"classSteinberg_1_1IPtr.html#a9ef8df82f56d037f33eedf88dc642ac1":[0,0,12,12],
+"classSteinberg_1_1IPtr.html#aa026503428fb71f2170fcf230a54ddea":[0,0,12,7],
+"classSteinberg_1_1IPtr.html#ab923ee4e03558fb6defc4420d53a2a09":[0,0,12,1],
+"classSteinberg_1_1IPtr.html#ac784799582d163bd4b0a10786dde5105":[0,0,12,4],
+"classSteinberg_1_1IPtr.html#ac962748be89328f823a11a469fc7fcf3":[0,0,12,13],
+"classSteinberg_1_1IPtr.html#ad90cd5b534f50a950d3a2faca6dc077d":[0,0,12,5],
+"classSteinberg_1_1IPtr.html#aded3f51510240b387624e8d2b7a595aa":[0,0,12,2],
+"classSteinberg_1_1ISizeableStream.html":[0,0,4],
+"classSteinberg_1_1ISizeableStream.html#a14a1cf32b76e98f867728d2b140d664c":[0,0,4,0],
+"classSteinberg_1_1ISizeableStream.html#a6c01cd5e45522b070c29ddc3402c9cbd":[0,0,4,1],
+"classSteinberg_1_1IString.html":[1,0,0,29],
+"classSteinberg_1_1IString.html":[2,0,0,26],
+"classSteinberg_1_1IString.html#a278b6bc34d672210e69dbde261f52cab":[1,0,0,29,4],
+"classSteinberg_1_1IString.html#a278b6bc34d672210e69dbde261f52cab":[2,0,0,26,4],
+"classSteinberg_1_1IString.html#a855f4116dd9824838ebc984adeccfe96":[1,0,0,29,1]
 };
