@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['mediatype_0',['MediaType',['../../vstinterfaces/namespaceSteinberg_1_1Vst.html#a5f0d28213b308d786ef7a1541d88368f',1,'Steinberg::Vst']]],
+  ['mediatype_0',['MediaType',['../../vstinterfaces/group__vst3typedef.html#ga5f0d28213b308d786ef7a1541d88368f',1,'Steinberg::Vst']]],
   ['mixeddata_1',['MixedData',['../../vstsdk/structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#a49bfd929dfe29358a6f72030d8ac1c2d',1,'Steinberg::Vst::UMP::IUniversalMidiPacketHandler']]],
   ['module_2',['Module',['../classSteinberg_1_1Vst_1_1Validator.html#ab626c416deed7a37c2f1e52f754d4bd3',1,'Steinberg::Vst::Validator']]]
 ];
