@@ -4,7 +4,7 @@ var namespace_v_s_t_g_u_i =
     [ "BitmapFilter", "namespace_v_s_t_g_u_i_1_1_bitmap_filter.html", "namespace_v_s_t_g_u_i_1_1_bitmap_filter" ],
     [ "Call", "namespace_v_s_t_g_u_i_1_1_call.html", [
       [ "FunctionCallback", "namespace_v_s_t_g_u_i_1_1_call.html#a8e79e769abdee84bcfcee4202d7aefdb", null ],
-      [ "later", "namespace_v_s_t_g_u_i_1_1_call.html#add69a1c2e8c0d79775abf9b545ce8453", null ]
+      [ "later", "namespace_v_s_t_g_u_i_1_1_call.html#af5c50081433f15f648dec99d9d160b47", null ]
     ] ],
     [ "CClipboardDetail", "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html", "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail" ],
     [ "CDrawMethods", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html", [
@@ -49,8 +49,8 @@ var namespace_v_s_t_g_u_i =
     [ "UIDescriptionPrivate", "namespace_v_s_t_g_u_i_1_1_u_i_description_private.html", "namespace_v_s_t_g_u_i_1_1_u_i_description_private" ],
     [ "UIViewCreator", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator" ],
     [ "VST3EditorInternal", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html", [
-      [ "parseSize", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html#a4acdd79e1135f9e72d1227a2cb0899af", null ],
-      [ "releaseSubController", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html#ae472a69c55a02a1b55a04c36ed746dd6", null ]
+      [ "parseSize", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html#a3fa5e1ea61dc076815c8bf71f90cb502", null ],
+      [ "releaseSubController", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html#aa0f6b4288ac078c4728da6fe39ecf41e", null ]
     ] ],
     [ "Xml", "namespace_v_s_t_g_u_i_1_1_xml.html", "namespace_v_s_t_g_u_i_1_1_xml" ],
     [ "AEffGUIEditor", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor.html", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor" ],
@@ -279,13 +279,13 @@ var namespace_v_s_t_g_u_i =
     [ "ZLibInputStream", "class_v_s_t_g_u_i_1_1_z_lib_input_stream.html", "class_v_s_t_g_u_i_1_1_z_lib_input_stream" ],
     [ "ZLibOutputStream", "class_v_s_t_g_u_i_1_1_z_lib_output_stream.html", "class_v_s_t_g_u_i_1_1_z_lib_output_stream" ],
     [ "ZoomGestureEvent", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event.html", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event" ],
-    [ "AssertionHandler", "namespace_v_s_t_g_u_i.html#a11231b1548c97b1a0ef491f349bb02ee", null ],
-    [ "AtomicReferenceCounted", "namespace_v_s_t_g_u_i.html#a286d045446df208150f004cdf34fd372", null ],
+    [ "AssertionHandler", "namespace_v_s_t_g_u_i.html#ad12bfb972769bcb8fff46fb6bf190fb1", null ],
+    [ "AtomicReferenceCounted", "namespace_v_s_t_g_u_i.html#adb65eb0fd1715f989f4680f576507ea7", null ],
     [ "CConstMenuItemIterator", "namespace_v_s_t_g_u_i.html#ac4c4a3f84ba1ad06cc2c6d897bbaa885", null ],
     [ "CCoord", "namespace_v_s_t_g_u_i.html#a6a872457eeeb5786083f968ca3fc0291", null ],
     [ "CFontRef", "namespace_v_s_t_g_u_i.html#a983d254a05cef7e1af39df9a3ba5cb31", null ],
     [ "CMenuItemIterator", "namespace_v_s_t_g_u_i.html#ac5d2d5ae2f6fa970821129ccaa21d2a8", null ],
-    [ "CMenuItemList", "namespace_v_s_t_g_u_i.html#a5f87a4ce5d72ac78a6d786dad058a442", null ],
+    [ "CMenuItemList", "namespace_v_s_t_g_u_i.html#ae866b004d82d1e368dd3f5bc8386b2e1", null ],
     [ "CParamDisplayValueToStringProc", "namespace_v_s_t_g_u_i.html#a01e4013e5947137c376d11ba08e65e97", null ],
     [ "CTextEditStringToValueProc", "namespace_v_s_t_g_u_i.html#aeb8a18f8dd4b9f3824fff995ced2ecaf", null ],
     [ "CViewAttributeID", "namespace_v_s_t_g_u_i.html#ab344f8ed42cf4fb22917bae466fa6897", null ],
@@ -351,9 +351,12 @@ var namespace_v_s_t_g_u_i =
       [ "kCursorNWSESize", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a44c3e21f1e30b19e4d6a4565c338ef32", null ],
       [ "kCursorCopy", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a0bd223915d667d13a3c8d93bf4cb968d", null ],
       [ "kCursorNotAllowed", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a317132e98927cafa870bc56157b21693", null ],
-      [ "kCursorHand", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a1ca05d526408fe0343c2aff9549b86be", null ],
+      [ "kCursorPointingHand", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609aeec2f8063a0e62852334010a0549c8e4", null ],
       [ "kCursorIBeam", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a5db586fd9be4aabbd25dbbd8b3735053", null ],
-      [ "kCursorCrosshair", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609aee923eaa4954aa9d385c5f55a9f01a67", null ]
+      [ "kCursorCrosshair", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609aee923eaa4954aa9d385c5f55a9f01a67", null ],
+      [ "kCursorMovableObject", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609ab3c3440a432ba36c51d19df2d462db03", null ],
+      [ "kCursorMoveObject", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a8b0b5f0e18dfaf7a7eb6922874a2df9d", null ],
+      [ "kCursorHand", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a1ca05d526408fe0343c2aff9549b86be", null ]
     ] ],
     [ "CDrawModeFlags", "namespace_v_s_t_g_u_i.html#a370d84d9d1737b1b4540a081630719a5", [
       [ "kAliasing", "namespace_v_s_t_g_u_i.html#a370d84d9d1737b1b4540a081630719a5a8f70930a006665848ee20c6e23792a26", null ],
@@ -518,90 +521,90 @@ var namespace_v_s_t_g_u_i =
       [ "AltModifier", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6a29caa75381017a69d54f7467dfa3fd", null ],
       [ "Equals", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a0ccb67e7eaae09d9e4078d161eeca100", null ]
     ] ],
-    [ "asInterface", "namespace_v_s_t_g_u_i.html#aff7501c984b2b4d9f13fcaf5fbfc3989", null ],
-    [ "asKeyboardEvent", "group__new__in__4__11.html#ga988aca5690efd8aa645b62b5d3e2e884", null ],
-    [ "asModifierEvent", "group__new__in__4__11.html#gaa8cd6995cf138b9b0aa31d0a8a4e5a27", null ],
-    [ "asMouseDownEvent", "group__new__in__4__11.html#gab000eba9fd774083f53f8b56a53a918d", null ],
-    [ "asMouseEvent", "group__new__in__4__11.html#ga8b7b87274799d37762f359e73944f832", null ],
-    [ "asMousePositionEvent", "group__new__in__4__11.html#ga3a260635856177d0762f807ba1b8e2cc", null ],
-    [ "begin", "namespace_v_s_t_g_u_i.html#a50b21f52717847d795a7911cf0deb531", null ],
-    [ "boxesForGauss", "namespace_v_s_t_g_u_i.html#ab9e45e525489bbbe87c3bdfded2b3bad", null ],
+    [ "asInterface", "namespace_v_s_t_g_u_i.html#ae441d9d401751310469b2ba75ef7fa77", null ],
+    [ "asKeyboardEvent", "group__new__in__4__11.html#gad3ddface7353cedd60e63157ed90e9c8", null ],
+    [ "asModifierEvent", "group__new__in__4__11.html#ga98ca899042462113b5b39f40433bcc03", null ],
+    [ "asMouseDownEvent", "group__new__in__4__11.html#gade54ccee6e74309deb553fad5eace0f6", null ],
+    [ "asMouseEvent", "group__new__in__4__11.html#ga95bbc88455eb2c9ef3d18f979f72db09", null ],
+    [ "asMousePositionEvent", "group__new__in__4__11.html#gacb2a0b731eed6fb529ca5ade8b6add76", null ],
+    [ "begin", "namespace_v_s_t_g_u_i.html#a08d856cad12896f58291f099d9732457", null ],
+    [ "boxesForGauss", "namespace_v_s_t_g_u_i.html#abcf6a3f540d01f3a4df8db781b6f08cb", null ],
     [ "buttonStateFromEventModifiers", "group__new__in__4__11.html#gacc93a453b03a037ebec4987bc8f30a90", null ],
     [ "buttonStateFromMouseEvent", "group__new__in__4__11.html#ga9e7a18104859beae1f325157d78ea771", null ],
-    [ "castKeyboardEvent", "group__new__in__4__11.html#ga2375dcff94f1ae33227a9e256d530699", null ],
-    [ "castMouseCancelEvent", "group__new__in__4__11.html#ga0d153d8418c33a96f02789a74eebeaa0", null ],
-    [ "castMouseDownEvent", "group__new__in__4__11.html#ga94dd31fe056f46c947b087278499abe5", null ],
-    [ "castMouseEnterEvent", "group__new__in__4__11.html#ga4e7b38bfaf50a66f152826563eb2f120", null ],
-    [ "castMouseEvent", "group__new__in__4__11.html#ga64e0fc5b29c20d7c5923d5701a637571", null ],
-    [ "castMouseExitEvent", "group__new__in__4__11.html#gaa59d6178ee14c8d0306fc243b1304a17", null ],
-    [ "castMouseMoveEvent", "group__new__in__4__11.html#gae1460811b80f07100233b8c83831dbd3", null ],
-    [ "castMousePositionEvent", "group__new__in__4__11.html#ga4a2a7e8a1d2f56cd6f8ecd88c162e0c4", null ],
-    [ "castMouseUpEvent", "group__new__in__4__11.html#ga38bbaa1f7abf5551e89ab9d2c19d0f49", null ],
-    [ "castMouseWheelEvent", "group__new__in__4__11.html#ga8b5dec4b03136eaacbeb1bea48958226", null ],
-    [ "castZoomGestureEvent", "group__new__in__4__11.html#ga13286e1ac3ca1faf4c9c2ad0e39015f1", null ],
-    [ "clamp", "namespace_v_s_t_g_u_i.html#a0920730c9c6e985a105e0b18d761ecbf", null ],
-    [ "clampNorm", "namespace_v_s_t_g_u_i.html#a666c97c45f7e59176759fe2c0eed8ab8", null ],
-    [ "convert", "namespace_v_s_t_g_u_i.html#a1cef5785ec00ac95fabe64e354a1a9ed", null ],
-    [ "convert", "namespace_v_s_t_g_u_i.html#a2954ba16852d6a301588a59bbd6f4298", null ],
-    [ "convert", "namespace_v_s_t_g_u_i.html#a2c5acc5e1d574cb0e303f3251c0438da", null ],
+    [ "castKeyboardEvent", "group__new__in__4__11.html#ga72eaa4704e183d6233c4c9cf42df973e", null ],
+    [ "castMouseCancelEvent", "group__new__in__4__11.html#gaea47e439b5007888b22a6611e0a34372", null ],
+    [ "castMouseDownEvent", "group__new__in__4__11.html#ga0c6b61604f95593156cb21423f653785", null ],
+    [ "castMouseEnterEvent", "group__new__in__4__11.html#ga0da14dc430887ec6c938dfbc72a494e3", null ],
+    [ "castMouseEvent", "group__new__in__4__11.html#gac58eda1c0fcfecc48bbcd4db4180f01e", null ],
+    [ "castMouseExitEvent", "group__new__in__4__11.html#ga3fea1c77f2004d3641a3f1078fef40f7", null ],
+    [ "castMouseMoveEvent", "group__new__in__4__11.html#gaeb713ab6ba4e2b6945fdefefb9592e00", null ],
+    [ "castMousePositionEvent", "group__new__in__4__11.html#gac7862a08e9b7c64482b9d55e72b09a10", null ],
+    [ "castMouseUpEvent", "group__new__in__4__11.html#gae3dfdd4a2dedd1c555cf4646bddc8a28", null ],
+    [ "castMouseWheelEvent", "group__new__in__4__11.html#ga5043a8eedce294c63e575beda7bc1adf", null ],
+    [ "castZoomGestureEvent", "group__new__in__4__11.html#ga7996f43f0a6f0a855f75e46bc6bd74e9", null ],
+    [ "clamp", "namespace_v_s_t_g_u_i.html#afd4c86ba716fdf40d84831822843016a", null ],
+    [ "clampNorm", "namespace_v_s_t_g_u_i.html#a97a959bfc6f6e0b27e925f30e3779225", null ],
+    [ "convert", "namespace_v_s_t_g_u_i.html#ae4e09ac9b31e63015a2529bb3b001954", null ],
+    [ "convert", "namespace_v_s_t_g_u_i.html#a72554073a9cef6518ba0ab5e90f42b09", null ],
+    [ "convert", "namespace_v_s_t_g_u_i.html#ada653f3803f48e88c81f1bb8e2fc6aa5", null ],
     [ "doAssert", "namespace_v_s_t_g_u_i.html#a61f906552ad31a1b0edc6d12218fa83d", null ],
-    [ "drawClipped", "namespace_v_s_t_g_u_i.html#ad76d477a7585215ba9a7bd238b4006c1", null ],
-    [ "dynamicPtrCast", "namespace_v_s_t_g_u_i.html#a8ad87e0342237fc206c1511a3f026e90", null ],
-    [ "dynamicPtrCast", "namespace_v_s_t_g_u_i.html#a5b01779501b6b79ead97aa1432a731d8", null ],
-    [ "end", "namespace_v_s_t_g_u_i.html#a8e1aedf4f34af4621c694f986e44ea50", null ],
-    [ "endianSwap", "namespace_v_s_t_g_u_i.html#a0a1a4ed607565f205d0104579706f751", null ],
+    [ "drawClipped", "namespace_v_s_t_g_u_i.html#a61ce8e0954f743f4396fe84df08f0efa", null ],
+    [ "dynamicPtrCast", "namespace_v_s_t_g_u_i.html#a2a8b0c5618f1860cc17a9bc00b6c5112", null ],
+    [ "dynamicPtrCast", "namespace_v_s_t_g_u_i.html#ac583ee24515aee11772b84e23f974719", null ],
+    [ "end", "namespace_v_s_t_g_u_i.html#a72937ea7ab5f5e115688282d8027c68d", null ],
+    [ "endianSwap", "namespace_v_s_t_g_u_i.html#a3d6471ce0a87d930ca7d0a6693756463", null ],
     [ "exit", "group__new__in__4__10.html#ga358d2e2397ca11ccd17553e3c40e7901", null ],
-    [ "finally", "namespace_v_s_t_g_u_i.html#ae9de256f98a8c3fbc87ba21cfa729d03", null ],
-    [ "findControlForTag", "namespace_v_s_t_g_u_i.html#ac7ea4dcd7f870e7c110579c81e0d34ac", null ],
-    [ "findViewController", "namespace_v_s_t_g_u_i.html#aec307aaa0dcbc9cfbd912829adce3e26", null ],
-    [ "FreeNodePlatformResources", "namespace_v_s_t_g_u_i.html#a7cb5b89e895e8161e14cc1a7576f478f", null ],
-    [ "fromVstVirtualKey", "namespace_v_s_t_g_u_i.html#a05eaae7df44e0f86cf101698629f4b25", null ],
-    [ "getCreatorRegistry", "namespace_v_s_t_g_u_i.html#a12b389440e74727e96efd2e644c49eca", null ],
-    [ "getGenericViewFactory", "namespace_v_s_t_g_u_i.html#a90d096d462285fac970543ca5b40edda", null ],
-    [ "getSplitViewController", "namespace_v_s_t_g_u_i.html#a35df62b75d01de3228916be4016f5b41", null ],
-    [ "getTooltipFromView", "namespace_v_s_t_g_u_i.html#a1b94ec5b03a0032379a659b1667370ff", null ],
-    [ "getViewController", "namespace_v_s_t_g_u_i.html#a81879511b35e82554318e487f8e83924", null ],
+    [ "finally", "namespace_v_s_t_g_u_i.html#a96b28b9c9adbba00aae653bd64e5d784", null ],
+    [ "findControlForTag", "namespace_v_s_t_g_u_i.html#aac8d4f664427cb963617361dd976bdd5", null ],
+    [ "findViewController", "namespace_v_s_t_g_u_i.html#aa776c0b3f1b205a1d8cc6a5741402a74", null ],
+    [ "FreeNodePlatformResources", "namespace_v_s_t_g_u_i.html#ac071928df01744b9ab2f020131232c91", null ],
+    [ "fromVstVirtualKey", "namespace_v_s_t_g_u_i.html#ad7b564797515bf4a690993a851e8c200", null ],
+    [ "getCreatorRegistry", "namespace_v_s_t_g_u_i.html#a3ea024da68ef884d603e29900152fd36", null ],
+    [ "getGenericViewFactory", "namespace_v_s_t_g_u_i.html#a10480eb9d1ff4a0aeb886f9186066331", null ],
+    [ "getSplitViewController", "namespace_v_s_t_g_u_i.html#ab25dd81cb13ee92511b6bbf80e53397a", null ],
+    [ "getTooltipFromView", "namespace_v_s_t_g_u_i.html#a9e2946e83b4d39ca26a82fc37c0b9659", null ],
+    [ "getViewController", "namespace_v_s_t_g_u_i.html#a4fe5229a1073206ee8671ea2a88a6408", null ],
     [ "hasAssertionHandler", "namespace_v_s_t_g_u_i.html#ab0411f6642b03599f6d293af2c17079c", null ],
-    [ "hasBit", "namespace_v_s_t_g_u_i.html#ad9eec0b3cf87e9731da4b76d93d19b2d", null ],
-    [ "indexOf", "namespace_v_s_t_g_u_i.html#aa4d24bcad0a295bee2916b585fa49a37", null ],
-    [ "indexOfTest", "namespace_v_s_t_g_u_i.html#a5fcad0e8827e0b13fb367c41575824bf", null ],
+    [ "hasBit", "namespace_v_s_t_g_u_i.html#a64ee641cfa5acff3b6d1640b8034b7e4", null ],
+    [ "indexOf", "namespace_v_s_t_g_u_i.html#a0e4aaf51cfebd26f3e39a53656c77812", null ],
+    [ "indexOfTest", "namespace_v_s_t_g_u_i.html#a7c163ed0030c8101aa84ef3c41235b38", null ],
     [ "init", "group__new__in__4__10.html#gacb669fbf9e184809ae58b5cfa4741088", null ],
-    [ "isLineBreakSeparator", "namespace_v_s_t_g_u_i.html#a6b2942893c05150a0705ccf67c1385c2", null ],
+    [ "isLineBreakSeparator", "namespace_v_s_t_g_u_i.html#a175a5c34bf33ae30700d212d3542d8c1", null ],
     [ "isSpace", "namespace_v_s_t_g_u_i.html#ac26b1f35554922a8ffe67f3f75d6cd09", null ],
-    [ "isUniformScaled", "namespace_v_s_t_g_u_i.html#a1ea43c3f4e1355d7381e382a1d95536c", null ],
-    [ "joinNearbyInvalidRects", "namespace_v_s_t_g_u_i.html#aa843a4d6bca1a131278d3ad74780ff03", null ],
-    [ "lastPathComponent", "namespace_v_s_t_g_u_i.html#a20db903426f90d56dc292c34b05a9db5", null ],
-    [ "MakeCColor", "namespace_v_s_t_g_u_i.html#a53e6f0665ddb08ff8ee3e3fca7af7151", null ],
-    [ "makeOptional", "namespace_v_s_t_g_u_i.html#adc53cc25199625e07b9d2ee1f80f9642", null ],
-    [ "makeOwned", "namespace_v_s_t_g_u_i.html#adac29f9de4785bff3a11b1166fc15c9a", null ],
-    [ "moveOldFile", "namespace_v_s_t_g_u_i.html#a1cf9ef372f63c82d34330fb1c29001c1", null ],
+    [ "isUniformScaled", "namespace_v_s_t_g_u_i.html#a91ded4561f0774517306c07368fd286c", null ],
+    [ "joinNearbyInvalidRects", "namespace_v_s_t_g_u_i.html#abf0b326c7d9697dd8c0ce8d29388f87c", null ],
+    [ "lastPathComponent", "namespace_v_s_t_g_u_i.html#aa82c6851e0bdb32857e701bedcb1f476", null ],
+    [ "MakeCColor", "namespace_v_s_t_g_u_i.html#a881b1a17406575d2fddb02dc4cd162e3", null ],
+    [ "makeOptional", "namespace_v_s_t_g_u_i.html#a8ea883f00c2913b47f7fcac1e7f3fb29", null ],
+    [ "makeOwned", "namespace_v_s_t_g_u_i.html#a2897be7c30768d8f7835efb5d53a7f3a", null ],
+    [ "moveOldFile", "namespace_v_s_t_g_u_i.html#a6565e55a049eec7949351a055020fa3d", null ],
     [ "noEvent", "namespace_v_s_t_g_u_i.html#a3a399ac6c0c4b47c5521578dff18f912", null ],
-    [ "normalizedToPlain", "namespace_v_s_t_g_u_i.html#a01ca69a89a5de82036eec96c6b5c5afc", null ],
-    [ "normalizedToSteps", "namespace_v_s_t_g_u_i.html#a2f9e59a7b70f055548276144d4faec2f", null ],
-    [ "operator!=", "namespace_v_s_t_g_u_i.html#a2f098fda52ec1fd8eb203de4ce456ada", null ],
-    [ "operator+", "namespace_v_s_t_g_u_i.html#abbcb3f1459349779a8301a21af3063c4", null ],
-    [ "operator==", "namespace_v_s_t_g_u_i.html#a6c60505ed3f074773d492f47bfb40aab", null ],
-    [ "owned", "namespace_v_s_t_g_u_i.html#a31cd61e85831d8cdbfaf78412af99748", null ],
-    [ "pathIsAbsolute", "namespace_v_s_t_g_u_i.html#a1579fde7bbebf26465723f50b1d70cb5", null ],
-    [ "plainToNormalized", "namespace_v_s_t_g_u_i.html#aefc8720a3354f04cd919828c183d2f2c", null ],
-    [ "radians", "namespace_v_s_t_g_u_i.html#a0c954fd7fdc04e81276fb809ca6431b8", null ],
-    [ "removeChildNode", "namespace_v_s_t_g_u_i.html#a4c4d209310d641f9b0fee394cc9d8757", null ],
-    [ "removeLastPathComponent", "namespace_v_s_t_g_u_i.html#ac05f8abc2a65f5c107bfe3f4ebcf59de", null ],
+    [ "normalizedToPlain", "namespace_v_s_t_g_u_i.html#ab79e3708bc6a17f00a5bc9fb2975d18b", null ],
+    [ "normalizedToSteps", "namespace_v_s_t_g_u_i.html#ad0c75c525c787dcede75ae5120feea45", null ],
+    [ "operator!=", "namespace_v_s_t_g_u_i.html#a000cca3ec3766ffb0bc9faa7cfc2dfc5", null ],
+    [ "operator+", "namespace_v_s_t_g_u_i.html#acc62467cef50fee9d0fb8ccb962b7e69", null ],
+    [ "operator==", "namespace_v_s_t_g_u_i.html#afc6a4ab99c775dfecbf4d1e5f30e2e49", null ],
+    [ "owned", "namespace_v_s_t_g_u_i.html#a395a83d0c66a2ff8e9783438a3dd2e29", null ],
+    [ "pathIsAbsolute", "namespace_v_s_t_g_u_i.html#a4a15b00a3f396ff95029b02997bcc78f", null ],
+    [ "plainToNormalized", "namespace_v_s_t_g_u_i.html#ac04eb5f1199b0becb385db6f5cd1140a", null ],
+    [ "radians", "namespace_v_s_t_g_u_i.html#a570f916012bfd4da75c05e7d6557d21c", null ],
+    [ "removeChildNode", "namespace_v_s_t_g_u_i.html#ac0f3df334bb7d3af53dea0baa7962170", null ],
+    [ "removeLastPathComponent", "namespace_v_s_t_g_u_i.html#ad8268fce27a595eb6c413d9e3176b0cc", null ],
     [ "renderBitmapOffscreen", "namespace_v_s_t_g_u_i.html#af0b09266cd230c80ad45b8451c8b11d9", null ],
     [ "setAssertionHandler", "namespace_v_s_t_g_u_i.html#a04a819c7a5ef1f7488cfcbd510e4912b", null ],
-    [ "setBit", "namespace_v_s_t_g_u_i.html#a60851feb2fabfcb2adcc31e240a56167", null ],
-    [ "shared", "namespace_v_s_t_g_u_i.html#a95bc321d9128ee5a415ae605b75664b0", null ],
-    [ "shouldStartDrag", "group__new__in__4__9.html#ga00b08005394f4061d1c0b5320426a91e", null ],
-    [ "staticPtrCast", "namespace_v_s_t_g_u_i.html#a296095986562547e979e4694f5053196", null ],
-    [ "staticPtrCast", "namespace_v_s_t_g_u_i.html#a2c1eb31931c0a20016ea3e16b2be67a4", null ],
-    [ "stepsToNormalized", "namespace_v_s_t_g_u_i.html#a361eaae3b9b583eac6802fe7de864810", null ],
-    [ "toString", "namespace_v_s_t_g_u_i.html#a27a9880d7e634c8ffcaaabf990d68e32", null ],
+    [ "setBit", "namespace_v_s_t_g_u_i.html#afc62e7dfbcbd4f90e5ab9a87ec202879", null ],
+    [ "shared", "namespace_v_s_t_g_u_i.html#aee219d95a6d17da540c26ef9951feaa5", null ],
+    [ "shouldStartDrag", "group__new__in__4__9.html#gab218802ff3016e52ac7dc3abb331945e", null ],
+    [ "staticPtrCast", "namespace_v_s_t_g_u_i.html#a6a973e5421cd9481de68ad5a73909005", null ],
+    [ "staticPtrCast", "namespace_v_s_t_g_u_i.html#a1723a75712e38e9b08a4cc7535591ba0", null ],
+    [ "stepsToNormalized", "namespace_v_s_t_g_u_i.html#aa21a1186c4869fd7b872418c07f0321b", null ],
+    [ "toString", "namespace_v_s_t_g_u_i.html#a1477db6c65effca97f3658df05ad749c", null ],
     [ "toVstKeyCode", "namespace_v_s_t_g_u_i.html#a9ff61fbaceee2ad20764752ba0e2aa6c", null ],
-    [ "toVstVirtualKey", "group__new__in__4__11.html#ga010ad00fd4fa3deaa934b01b4a4e1ba1", null ],
+    [ "toVstVirtualKey", "group__new__in__4__11.html#ga36a2c5cf70fdd5d947276ae40e061b3a", null ],
     [ "trim", "namespace_v_s_t_g_u_i.html#a879a9ac72cbabe826e1b928aeba70935", null ],
-    [ "unixfyPath", "namespace_v_s_t_g_u_i.html#aa5195595ec9efa7c52eb3830247ea848", null ],
-    [ "viewHasTooltip", "namespace_v_s_t_g_u_i.html#ab235b5451d2d91c04e4f8c5b23e2269c", null ],
-    [ "writeEndianSwap", "namespace_v_s_t_g_u_i.html#a6fac9ee9d2fe6ee3927ce6174612d338", null ],
+    [ "unixfyPath", "namespace_v_s_t_g_u_i.html#a89f6f7584b245dc5a4050d2d0db9eecb", null ],
+    [ "viewHasTooltip", "namespace_v_s_t_g_u_i.html#a0ed00417e359355e46f35ff8e1e4e52f", null ],
+    [ "writeEndianSwap", "namespace_v_s_t_g_u_i.html#a202cedc1a740710d736ef2701d6f8bd6", null ],
     [ "assertionHandler", "namespace_v_s_t_g_u_i.html#ac8534d324abb28a3408624afe03d14df", null ],
     [ "globalFonts", "namespace_v_s_t_g_u_i.html#a468cfdbb3f7b47818718b6cbedd64a25", null ],
     [ "kBlackCColor", "namespace_v_s_t_g_u_i.html#a3a66709c3ab3f7c308dd4dba9ad3174a", null ],
