@@ -1,30 +1,21 @@
 var NAVTREEINDEX30 =
 {
-"struct_v_s_t_g_u_i_1_1_get_view_options.html#aa8275f6f0cdbaa6eb5e2ad219a1e4426":[10,0,1,126,7],
-"struct_v_s_t_g_u_i_1_1_get_view_options.html#aac003ad010797e5b85321b1cf105f655":[9,0,2,134,5],
-"struct_v_s_t_g_u_i_1_1_get_view_options.html#aac003ad010797e5b85321b1cf105f655":[10,0,1,126,5],
-"struct_v_s_t_g_u_i_1_1_get_view_options.html#afaec3e20ae5345fba2728a8c48c976e4":[10,0,1,126,0],
-"struct_v_s_t_g_u_i_1_1_get_view_options.html#afaec3e20ae5345fba2728a8c48c976e4":[9,0,2,134,0],
-"struct_v_s_t_g_u_i_1_1_get_view_options.html#afdc03ee9469f45acca29830ee152bf9d":[9,0,2,134,3],
-"struct_v_s_t_g_u_i_1_1_get_view_options.html#afdc03ee9469f45acca29830ee152bf9d":[10,0,1,126,3],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html":[10,0,1,127],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html":[9,0,2,135],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#a061abdaa46918e3d3c3c7ba04f0e20b3":[9,0,2,135,4],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#a061abdaa46918e3d3c3c7ba04f0e20b3":[9,0,1,135,4],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#a061abdaa46918e3d3c3c7ba04f0e20b3":[10,0,1,127,4],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#a3729ad9883813d03460c08eb8d495b2f":[9,0,1,135,5],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#a3729ad9883813d03460c08eb8d495b2f":[10,0,1,127,5],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#a3729ad9883813d03460c08eb8d495b2f":[9,0,2,135,5],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#a5925ab03b3f438f6d64dac4dbacc5f71":[9,0,1,135,2],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#a5925ab03b3f438f6d64dac4dbacc5f71":[10,0,1,127,2],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#a5925ab03b3f438f6d64dac4dbacc5f71":[9,0,2,135,2],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#a844226a113e4b2e1a1899336d75271fe":[9,0,2,135,0],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#a844226a113e4b2e1a1899336d75271fe":[9,0,1,135,0],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#a844226a113e4b2e1a1899336d75271fe":[10,0,1,127,0],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#acbba89c98e133923c0b93fa473bcd597":[9,0,2,135,1],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#acbba89c98e133923c0b93fa473bcd597":[9,0,1,135,1],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#acbba89c98e133923c0b93fa473bcd597":[10,0,1,127,1],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#ad3950c62dbda1b9f0c9a0a946ca1b7c3":[9,0,2,135,6],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#ad3950c62dbda1b9f0c9a0a946ca1b7c3":[9,0,1,135,6],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#ad3950c62dbda1b9f0c9a0a946ca1b7c3":[10,0,1,127,6],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#aedc2a911789abd2ee459f6ebffee0167":[9,0,1,135,7],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#aedc2a911789abd2ee459f6ebffee0167":[10,0,1,127,7],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#aedc2a911789abd2ee459f6ebffee0167":[9,0,2,135,7],
+"struct_v_s_t_g_u_i_1_1_global_fonts.html#af2d888dc7ccfdac4a8ad92f9c10426e8":[9,0,1,135,3],
 "struct_v_s_t_g_u_i_1_1_global_fonts.html#af2d888dc7ccfdac4a8ad92f9c10426e8":[10,0,1,127,3],
-"struct_v_s_t_g_u_i_1_1_global_fonts.html#af2d888dc7ccfdac4a8ad92f9c10426e8":[9,0,2,135,3],
 "struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html":[8,1,11,2,0],
 "struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a03a4f87a4ca9bc90c40e11b69e866637":[8,1,11,2,0,0],
 "struct_v_s_t_g_u_i_1_1_i_list_control_drawer_1_1_row.html#a19ab353898931195f8f694c836fbb542":[8,1,11,2,0,6],
@@ -38,31 +29,31 @@ var NAVTREEINDEX30 =
 "struct_v_s_t_g_u_i_1_1_keyboard_event.html#a37312625fe3bfb9f5cbc48c937cd9fc7":[8,1,3,17,1],
 "struct_v_s_t_g_u_i_1_1_keyboard_event.html#aef096c3bbf6e750546c1c2a1da7992e5":[8,1,3,17,2],
 "struct_v_s_t_g_u_i_1_1_keyboard_event.html#af6597fffaeac6367c562ddf853cd8241":[8,1,3,17,3],
-"struct_v_s_t_g_u_i_1_1_listener_provider.html":[9,0,2,182],
+"struct_v_s_t_g_u_i_1_1_listener_provider.html":[9,0,1,182],
 "struct_v_s_t_g_u_i_1_1_listener_provider.html":[10,0,1,174],
+"struct_v_s_t_g_u_i_1_1_listener_provider.html#a1e1b586e764c0f7c2bf3cb8679b091e3":[9,0,1,182,3],
 "struct_v_s_t_g_u_i_1_1_listener_provider.html#a1e1b586e764c0f7c2bf3cb8679b091e3":[10,0,1,174,3],
-"struct_v_s_t_g_u_i_1_1_listener_provider.html#a1e1b586e764c0f7c2bf3cb8679b091e3":[9,0,2,182,3],
+"struct_v_s_t_g_u_i_1_1_listener_provider.html#a4fdc3214526cfa67a06ed58018a2ac7c":[9,0,1,182,5],
 "struct_v_s_t_g_u_i_1_1_listener_provider.html#a4fdc3214526cfa67a06ed58018a2ac7c":[10,0,1,174,5],
-"struct_v_s_t_g_u_i_1_1_listener_provider.html#a4fdc3214526cfa67a06ed58018a2ac7c":[9,0,2,182,5],
-"struct_v_s_t_g_u_i_1_1_listener_provider.html#aa68a6d2df1ead0b7ab35597dba6a69b1":[9,0,2,182,1],
+"struct_v_s_t_g_u_i_1_1_listener_provider.html#aa68a6d2df1ead0b7ab35597dba6a69b1":[9,0,1,182,1],
 "struct_v_s_t_g_u_i_1_1_listener_provider.html#aa68a6d2df1ead0b7ab35597dba6a69b1":[10,0,1,174,1],
+"struct_v_s_t_g_u_i_1_1_listener_provider.html#abedbd70f0d9b667c824e6acd43bbce9d":[9,0,1,182,2],
 "struct_v_s_t_g_u_i_1_1_listener_provider.html#abedbd70f0d9b667c824e6acd43bbce9d":[10,0,1,174,2],
-"struct_v_s_t_g_u_i_1_1_listener_provider.html#abedbd70f0d9b667c824e6acd43bbce9d":[9,0,2,182,2],
+"struct_v_s_t_g_u_i_1_1_listener_provider.html#ae5780255e762641429a0ead4d9c119c9":[9,0,1,182,0],
 "struct_v_s_t_g_u_i_1_1_listener_provider.html#ae5780255e762641429a0ead4d9c119c9":[10,0,1,174,0],
-"struct_v_s_t_g_u_i_1_1_listener_provider.html#ae5780255e762641429a0ead4d9c119c9":[9,0,2,182,0],
-"struct_v_s_t_g_u_i_1_1_listener_provider.html#aef83aafdad21804f3a48eb7410d44c8a":[9,0,2,182,4],
+"struct_v_s_t_g_u_i_1_1_listener_provider.html#aef83aafdad21804f3a48eb7410d44c8a":[9,0,1,182,4],
 "struct_v_s_t_g_u_i_1_1_listener_provider.html#aef83aafdad21804f3a48eb7410d44c8a":[10,0,1,174,4],
+"struct_v_s_t_g_u_i_1_1_malloc_allocator.html":[9,0,1,183],
 "struct_v_s_t_g_u_i_1_1_malloc_allocator.html":[10,0,1,175],
-"struct_v_s_t_g_u_i_1_1_malloc_allocator.html":[9,0,2,183],
+"struct_v_s_t_g_u_i_1_1_malloc_allocator.html#a3527a80b47a8a8fc94f660b46be13187":[9,0,1,183,0],
 "struct_v_s_t_g_u_i_1_1_malloc_allocator.html#a3527a80b47a8a8fc94f660b46be13187":[10,0,1,175,0],
-"struct_v_s_t_g_u_i_1_1_malloc_allocator.html#a3527a80b47a8a8fc94f660b46be13187":[9,0,2,183,0],
+"struct_v_s_t_g_u_i_1_1_malloc_allocator.html#af4145414e742b74200f16e3d5f43d9f2":[9,0,1,183,1],
 "struct_v_s_t_g_u_i_1_1_malloc_allocator.html#af4145414e742b74200f16e3d5f43d9f2":[10,0,1,175,1],
-"struct_v_s_t_g_u_i_1_1_malloc_allocator.html#af4145414e742b74200f16e3d5f43d9f2":[9,0,2,183,1],
+"struct_v_s_t_g_u_i_1_1_modal_view_session.html":[9,0,1,185],
 "struct_v_s_t_g_u_i_1_1_modal_view_session.html":[10,0,1,177],
-"struct_v_s_t_g_u_i_1_1_modal_view_session.html":[9,0,2,185],
+"struct_v_s_t_g_u_i_1_1_modal_view_session.html#a08771b4d9efc828eae3a1581d6a46c1f":[9,0,1,185,0],
 "struct_v_s_t_g_u_i_1_1_modal_view_session.html#a08771b4d9efc828eae3a1581d6a46c1f":[10,0,1,177,0],
-"struct_v_s_t_g_u_i_1_1_modal_view_session.html#a08771b4d9efc828eae3a1581d6a46c1f":[9,0,2,185,0],
-"struct_v_s_t_g_u_i_1_1_modal_view_session.html#ad39ca9b34b02113ca0befe08c1d0b9b2":[9,0,2,185,1],
+"struct_v_s_t_g_u_i_1_1_modal_view_session.html#ad39ca9b34b02113ca0befe08c1d0b9b2":[9,0,1,185,1],
 "struct_v_s_t_g_u_i_1_1_modal_view_session.html#ad39ca9b34b02113ca0befe08c1d0b9b2":[10,0,1,177,1],
 "struct_v_s_t_g_u_i_1_1_modifier_event.html":[8,1,3,3],
 "struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed":[8,1,3,3,0],
@@ -168,6 +159,7 @@ var NAVTREEINDEX30 =
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_for_window_config.html#ac8bf691c5cac63dde81e5c16d4cc180f":[8,2,18,0],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html":[8,2,4],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a0a9236854e536279a7b1aeba9ca8237c":[8,2,4,2],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a0bcdc6592e80d671f7b4dda18188d366":[8,2,4,7],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a1d1cfd8ffb84e947f82999c682b666a7":[8,2,4,0],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a1d1cfd8ffb84e947f82999c682b666a7a27118326006d3829667a400ad23d5d98":[8,2,4,0,2],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a1d1cfd8ffb84e947f82999c682b666a7a88183b946cc5f0e8c96b2e66e1c74a7e":[8,2,4,0,0],
@@ -175,7 +167,6 @@ var NAVTREEINDEX30 =
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a47112a46547df7760e7994aeea220774":[8,2,4,6],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a57ef39e8def0d695ce9f6744ea05c48c":[8,2,4,4],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#a5ddea8b3bf7c3b8009d9da66ca21096b":[8,2,4,3],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#abe2f65e757b87baa165a12f3e5db3367":[8,2,4,7],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#ae1adbce218e7a9d09164012443191d24":[8,2,4,5],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_config_value.html#aeddbf396635afaca14f099c875f78bd0":[8,2,4,1],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html":[8,2,19],
@@ -184,13 +175,13 @@ var NAVTREEINDEX30 =
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_info.html#aef60a36d5f365618e052256cf56189c7":[8,2,19,2],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_init.html":[8,2,5],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_init.html#a5150c4261a4bcb40d81b8c7a8cc8f9b6":[8,2,5,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html":[9,0,2,11,1,0],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html":[9,0,1,11,1,0],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html":[10,0,1,5,1,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a1c3ad1b57347be66108fa9b491d08bd4":[9,0,2,11,1,0,0],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a1c3ad1b57347be66108fa9b491d08bd4":[9,0,1,11,1,0,0],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a1c3ad1b57347be66108fa9b491d08bd4":[10,0,1,5,1,0,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a729f5857fdc27ff281e8d333192b5124":[9,0,2,11,1,0,1],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a729f5857fdc27ff281e8d333192b5124":[9,0,1,11,1,0,1],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a729f5857fdc27ff281e8d333192b5124":[10,0,1,5,1,0,1],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a90e077d0b8d7b50eeb7c3ed2c98c5975":[9,0,2,11,1,0,2],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a90e077d0b8d7b50eeb7c3ed2c98c5975":[9,0,1,11,1,0,2],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_async_1_1_group.html#a90e077d0b8d7b50eeb7c3ed2c98c5975":[10,0,1,5,1,0,2],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_command.html":[8,2,22],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_command.html#a820ae9ca94c72fb06fcac9cc544ea24b":[8,2,22,1],
@@ -201,23 +192,23 @@ var NAVTREEINDEX30 =
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#a738d31f7ed30f4c0c8f0467146a72a21":[8,2,29,2],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#aa2ba01b9ce98322b1207b09e13d4cae6":[8,2,29,3],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_config.html#aca0d6bfe279af0abacbe7b1c525dadbe":[8,2,29,4],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html":[9,0,1,11,5,6],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html":[10,0,1,5,2,6],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html":[9,0,2,11,5,6],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a0c83c7d03e9268f35430c48354a0a992":[9,0,1,11,5,6,0],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a0c83c7d03e9268f35430c48354a0a992":[10,0,1,5,2,6,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a0c83c7d03e9268f35430c48354a0a992":[9,0,2,11,5,6,0],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a5ff769fa908d21f3af50f4e162712d63":[9,0,2,11,5,6,5],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a5ff769fa908d21f3af50f4e162712d63":[9,0,1,11,5,6,5],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a5ff769fa908d21f3af50f4e162712d63":[10,0,1,5,2,6,5],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a6e859de0af108f29de36b80df7ddc78e":[9,0,1,11,5,6,1],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a6e859de0af108f29de36b80df7ddc78e":[10,0,1,5,2,6,1],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a6e859de0af108f29de36b80df7ddc78e":[9,0,2,11,5,6,1],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a7d02ef812e2d2f74d9dc5f44f2edfb42":[9,0,1,11,5,6,6],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a7d02ef812e2d2f74d9dc5f44f2edfb42":[10,0,1,5,2,6,6],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a7d02ef812e2d2f74d9dc5f44f2edfb42":[9,0,2,11,5,6,6],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a9613d4ab584696b192c3ece999fd2d0b":[9,0,1,11,5,6,7],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a9613d4ab584696b192c3ece999fd2d0b":[10,0,1,5,2,6,7],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#a9613d4ab584696b192c3ece999fd2d0b":[9,0,2,11,5,6,7],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#abca60daa4ae17f01e3206f1ad3beefbc":[9,0,1,11,5,6,3],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#abca60daa4ae17f01e3206f1ad3beefbc":[10,0,1,5,2,6,3],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#abca60daa4ae17f01e3206f1ad3beefbc":[9,0,2,11,5,6,3],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#ad71bee8aed60d30eca6061ef9e5ada3e":[9,0,2,11,5,6,4],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#ad71bee8aed60d30eca6061ef9e5ada3e":[9,0,1,11,5,6,4],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#ad71bee8aed60d30eca6061ef9e5ada3e":[10,0,1,5,2,6,4],
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#af01d963f5eff1016346f88e7eccd5ed8":[9,0,2,11,5,6,2],
+"struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#af01d963f5eff1016346f88e7eccd5ed8":[9,0,1,11,5,6,2],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc_1_1_value_calls.html#af01d963f5eff1016346f88e7eccd5ed8":[10,0,1,5,2,6,2],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_configuration.html":[8,2,35],
 "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_configuration.html#a079f062c4955dddcbe528b0b9e00d6e5":[8,2,35,4],
@@ -249,5 +240,14 @@ var NAVTREEINDEX30 =
 "struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#a549718c433e9cbf0d22c29234c217e45":[8,1,11,5,0,5],
 "struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#a7e70936009a642e08f3d72aa6d93f6b6":[8,1,11,5,0,8],
 "struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#a7f6cf1112aba1291073b6ca93399b9ea":[8,1,11,5,0,0],
-"struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#a81fc04b2297a2dcda6e45d24438ad4df":[8,1,11,5,0,1]
+"struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#a81fc04b2297a2dcda6e45d24438ad4df":[8,1,11,5,0,1],
+"struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#a84df09833959e44abb7d40b068e650c0":[8,1,11,5,0,2],
+"struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#aa8d5895881fbdb8d611e7758a5aa907f":[8,1,11,5,0,4],
+"struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#ae670d3f238d531572257101fc3f546c3":[8,1,11,5,0,3],
+"struct_v_s_t_g_u_i_1_1_string_list_control_drawer_1_1_impl.html#af74d43f6a2e3bcb319c6382d8bda184d":[8,1,11,5,0,9],
+"struct_v_s_t_g_u_i_1_1_trim_options.html":[9,0,1,217],
+"struct_v_s_t_g_u_i_1_1_trim_options.html":[10,0,1,209],
+"struct_v_s_t_g_u_i_1_1_trim_options.html#a4ed60a215dbee2b42e999dcaf3a92978":[9,0,1,217,0],
+"struct_v_s_t_g_u_i_1_1_trim_options.html#a4ed60a215dbee2b42e999dcaf3a92978":[10,0,1,209,0],
+"struct_v_s_t_g_u_i_1_1_trim_options.html#a668a317a4337b0cada273f26a0f34ab7":[9,0,1,217,1]
 };
